/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

/**
 * A rule of a PCFG.
 *
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
abstract public class Rule {

	/**
	 * The score associated with this rule.
	 */
	private double score;

	/**
	 * Constructs a new rule.
	 */
	public Rule() {
		this.score = Double.NEGATIVE_INFINITY;
	}

	/**
	 * Returns the left-hand side of this rule.
	 *
	 * @return the left-hand side of this rule
	 */
	abstract public int getLHS();

	/**
	 * Returns the score of this rule.
	 *
	 * @return the score of this rule
	 */
	public double getScore() {
		return score;
	}

	/**
	 * Replaces the score of this rule with the specified value.
	 *
	 * @param score the new score of this rule
	 */
	public void setScore(double score) {
		this.score = score;
	}
}
