/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

import java.util.Deque;
import java.util.LinkedList;
import java.util.List;

/**
 * A fallback implementation of the
 * <code>Parser</code> interface.
 *
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
public class StupidParser implements Parser {

	/**
	 * The grammar used by this parser.
	 */
	private final Grammar grammar;

	/**
	 * Constructs a new parser based on the specified grammar.
	 *
	 * @param grammar the grammar to be used by the parser
	 */
	public StupidParser(Grammar grammar) {
		this.grammar = grammar;
	}

	/**
	 * Returns a dummy parse tree for the specified tag sequence.
	 *
	 * @param tags a sequence of part-of-speech tags
	 * @return the right-branching binary tree whose leaves are the specified
	 * tags, and whose inner nodes are labelled with the root symbol of the
	 * grammar
	 */
	public Tree getBestParse(List<String> tags) {
		String rootSymbol = grammar.getCategory(grammar.getRootCode());
		Deque<Tree> trees = new LinkedList<Tree>();
		Tree root = new Tree(rootSymbol);
		for (String token : tags) {
			Tree tagNode = new Tree(rootSymbol);
			Tree tokenNode = new Tree(token);
			tagNode.addAsRightmostSubtree(tokenNode);
			trees.addLast(tagNode);
		}
		while (trees.size() > 1) {
			Tree subtree1 = trees.removeLast();
			Tree subtree0 = trees.removeLast();
			Tree tree = new Tree(rootSymbol);
			tree.addAsRightmostSubtree(subtree0);
			tree.addAsRightmostSubtree(subtree1);
			trees.addLast(tree);
		}
		root.addAsRightmostSubtree(trees.removeLast());
		return root;
	}
}
