/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

/**
 * Sends the next tree through a chain of tree transformers.
 *
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
public class TransformerHandler extends DefaultTreeHandler {

    /**
     * The tree transformer to be applied to the trees in the stream.
     */
    private final TreeTransformer transformer;

    /**
     * Constructs a new handler with the specified transformer.
     *
     * @param transformer the tree transformer to be applied to the trees in the
     * stream
     */
    public TransformerHandler(TreeTransformer transformer) {
        super();
        this.transformer = transformer;
    }

    /**
     * Transforms the specified tree and sends it to the next handler in the
     * chain.
     *
     * @param tree the next tree in the stream
     */
    @Override
    public void next(Tree tree) {
        super.next(transformer.transform(tree));
    }
}
