/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

import java.io.*;

/**
 * A tree handler that prints the trees in a stream.
 *
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
public class TreePrinter extends DefaultTreeHandler {

    /**
     * The internal writer.
     */
    private final PrintWriter writer;
    /**
     * Flag to indicate whether the output stream underlying the internal writer
     * should be closed at the end of the stream of trees.
     */
    private final boolean close;

    /**
     * Constructs a new printer that prints trees to the standard output stream.
     */
    public TreePrinter() {
        super();
        this.writer = new PrintWriter(System.out, true);
        this.close = false;
    }

    /**
     * Constructs a new printer that prints trees to the specified file.
     *
     * @param file the file to which to print the trees to
     * @throws IOException if the file cannot be found
     */
    public TreePrinter(File file) throws IOException {
        super();
        this.writer = new PrintWriter(new BufferedWriter(new FileWriter(file)));
        this.close = true;
    }

    @Override
    public void next(Tree tree) {
        writer.println(tree);
        super.next(tree);
    }

    @Override
    public void exit() {
        if (close) {
            writer.close();
        }
        super.exit();
    }
}
