/*
 * See the file "LICENSE" for the full license governing this code.
 */
package up;

/**
 * A unary rule of a PCFG. This is a rule of the form A → B.
 * 
 * @author Marco Kuhlmann <marco.kuhlmann@lingfil.uu.se>
 */
public class UnaryRule extends Rule {

	/**
	 * The left-hand side of this rule.
	 */
	private final int lhs;
	/**
	 * The right-hand side of this rule.
	 */
	private final int rhs;

	/**
	 * Constructs a new unary rule.
	 *
	 * @param lhs the left-hand side of the new rule
	 * @param rhs the right-hand side of the new rule
	 */
	public UnaryRule(int lhs, int rhs) {
		super();
		this.lhs = lhs;
		this.rhs = rhs;
	}

	public int getLHS() {
		return lhs;
	}

	/**
	 * Returns the right-hand side of this rule.
	 *
	 * @return the right-hand side of this rule
	 */
	public int getRHS() {
		return rhs;
	}

	/**
	 * Tests whether this rule is equal to the specified object.
	 *
	 * @param obj the object to compare with
	 * @return <code>true</code> iff this rule is equal to the specified object
	 */
	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final UnaryRule other = (UnaryRule) obj;
		if (this.lhs != other.lhs) {
			return false;
		}
		if (this.rhs != other.rhs) {
			return false;
		}
		return true;
	}

	/**
	 * Returns the hash code of this rule.
	 *
	 * @return the hash code of this rule
	 */
	@Override
	public int hashCode() {
		int hash = 3;
		hash = 43 * hash + this.lhs;
		hash = 43 * hash + this.rhs;
		return hash;
	}
}
